@@ -624,8 +624,11 @@ static proc_info_t *proc_cache_add_at_hash_index(
 	if (p->cmdline == NULL)
 		p->kernel_thread = true;
 
-	if ((p->cmdline == NULL) || (opt_flags & OPT_CMD_COMM))
+	if ((p->cmdline == NULL) || (opt_flags & OPT_CMD_COMM)) {
+		if (p->cmdline)
+			free(p->cmdline);
 		p->cmdline = get_pid_comm(pid);
+	}
 	p->next = proc_cache_hash[h];
 	proc_cache_hash[h] = p;
 
@@ -975,7 +978,7 @@ static int mem_get_by_proc(const pid_t pid, mem_info_t ** const mem)
 		for (p = pids; p; p = p->next) {
 			if (p->pid == pid)
 				break;
-			if (p->name && strcmp(p->name, tmp) == 0)
+			if (tmp && p->name && strcmp(p->name, tmp) == 0)
 				break;
 		}
 		if (!p)
@@ -1233,7 +1236,9 @@ static int mem_dump(
 	mem_to_str((double)t_rss, s_rss, sizeof(s_rss));
 
 	if (!(opt_flags & OPT_QUIET))
-		df.df_printf("Total: %9s %9s %9s %9s\n\n", s_swap, s_uss, s_pss, s_rss);
+		df.df_printf(" %-*.*s %9s %9s %9s %9s\n\n",
+			pid_size, pid_size, "Total:",
+			s_swap, s_uss, s_pss, s_rss);
 
 	if (json) {
 		(void)fprintf(json, "    ],\n");
